aboutsummaryrefslogtreecommitdiff
path: root/packages/taler-wallet-cli/src/lint.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/taler-wallet-cli/src/lint.ts')
-rw-r--r--packages/taler-wallet-cli/src/lint.ts16
1 files changed, 13 insertions, 3 deletions
diff --git a/packages/taler-wallet-cli/src/lint.ts b/packages/taler-wallet-cli/src/lint.ts
index 61b6d622f..e6155b48e 100644
--- a/packages/taler-wallet-cli/src/lint.ts
+++ b/packages/taler-wallet-cli/src/lint.ts
@@ -198,6 +198,16 @@ async function checkWireConfig(context: LintContext): Promise<void> {
}
}
+ if (accounts.size === 0) {
+ console.log(
+ "error: No accounts configured (no sections EXCHANGE_ACCOUNT-*).",
+ );
+ if (!context.cont) {
+ console.log("Aborting further checks.");
+ process.exit(1);
+ }
+ }
+
for (const acc of accounts) {
if (!credentials.has(acc)) {
console.log(
@@ -207,19 +217,19 @@ async function checkWireConfig(context: LintContext): Promise<void> {
}
for (const acc of accounts) {
// test debit history
{
const res = await sh(
context,
"su -l --shell /bin/sh " +
- "-c 'taler-exchange-wire-gateway-client -s exchange-accountcredentials-${acc} --debit-history'" +
+ `-c 'taler-exchange-wire-gateway-client -s exchange-accountcredentials-${acc} --credit-history'` +
"taler-exchange-wire",
);
if (res.status != 0) {
console.log(res.stdout);
console.log(res.stderr);
console.log(
- "error: Could not run wirewatch. Please review logs above.",
+ "error: Could not run taler-exchange-wire-gateway-client. Please review logs above.",
);
if (!context.cont) {
console.log("Aborting further checks.");
@@ -207,19 +217,19 @@ async function checkWireConfig(context: LintContext): Promise<void> {
}
for (const acc of accounts) {
- // test debit history
+ // test credit history
{
const res = await sh(